==> bbctrl-1.0.4-rc11.tar.bz2: bbctrl-1.0.4/src/js/modbus-reg.js <==
/******************************************************************************\

                  This file is part of the Buildbotics firmware.

         Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.

          This Source describes Open Hardware and is licensed under the
                                  CERN-OHL-S v2.

          You may redistribute and modify this Source and make products
     using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).
            This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED
     WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS
      FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable
                                   conditions.

                 Source location: https://github.com/buildbotics

       As per CERN-OHL-S v2 section 4, should You produce hardware based on
     these sources, You must maintain the Source Location clearly visible on
     the external case of the CNC Controller or other product you make using
                                   this Source.

                 For more information, email info@buildbotics.com

\******************************************************************************/

'use strict'


module.exports = {
  replace: true,
  template: '#modbus-reg-template',
  props: ['index', 'model', 'template', 'enable'],


  computed: {
    has_user_value: function () {
      var type = this.model['reg-type'];

      return type.indexOf('write') != -1 || type.indexOf('fixed') != -1 ||
        type.indexOf('scaled') != -1;
    }
  },


  methods: {
    change: function () {this.$dispatch('input-changed')}
  }
}

==> bbctrl-2.0.0-rc5.tar.bz2: bbctrl-2.0.0/src/js/modbus-reg.js <==
/******************************************************************************\

                  This file is part of the Buildbotics firmware.

         Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.

          This Source describes Open Hardware and is licensed under the
                                  CERN-OHL-S v2.

          You may redistribute and modify this Source and make products
     using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).
            This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED
     WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS
      FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable
                                   conditions.

                 Source location: https://github.com/buildbotics

       As per CERN-OHL-S v2 section 4, should You produce hardware based on
     these sources, You must maintain the Source Location clearly visible on
     the external case of the CNC Controller or other product you make using
                                   this Source.

                 For more information, email info@buildbotics.com

\******************************************************************************/



module.exports = {
  template: '#modbus-reg-template',
  replace: true,
  props: ['index', 'model', 'template', 'enable'],


  computed: {
    has_user_value() {
      let type = this.model['reg-type']

      return type.indexOf('write') != -1 || type.indexOf('fixed') != -1 ||
        type.indexOf('scaled') != -1
    }
  },


  methods: {
    change() {this.$dispatch('input-changed')}
  }
}
